@@ -8,8 +8,8 @@
 #ifndef ASKUSERACTIONINTERFACE_H
 #define ASKUSERACTIONINTERFACE_H
 
-#include <kiocore_export.h>
 #include <kio/jobuidelegateextension.h> // RenameDialog_Result, SkipDialog_Result
+#include <kiocore_export.h>
 
 #include <QObject>
 
@@ -17,8 +17,8 @@
 
 class KJob;
 
-namespace KIO {
-
+namespace KIO
+{
 class AskUserActionInterfacePrivate;
 
 /**
@@ -84,10 +84,10 @@ public:
                                KIO::RenameDialog_Options options,
                                KIO::filesize_t sizeSrc,
                                KIO::filesize_t sizeDest,
-                               const QDateTime &ctimeSrc,
-                               const QDateTime &ctimeDest,
-                               const QDateTime &mtimeSrc,
-                               const QDateTime &mtimeDest) = 0;
+                               const QDateTime &ctimeSrc = {},
+                               const QDateTime &ctimeDest = {},
+                               const QDateTime &mtimeSrc = {},
+                               const QDateTime &mtimeDest = {}) = 0;
 
     /**
      * @relates KIO::SkipDialog
@@ -101,9 +101,7 @@ public:
      * @param error_text the error text to show to the user (usually the string returned
      *               by KJob::errorText())
      */
-    virtual void askUserSkip(KJob *job,
-                             KIO::SkipDialog_Options options,
-                             const QString &errorText) = 0;
+    virtual void askUserSkip(KJob *job, KIO::SkipDialog_Options options, const QString &errorText) = 0;
 
     /**
      * The type of deletion.
@@ -111,8 +109,8 @@ public:
      * Used by askUserDelete().
      */
     enum DeletionType {
-        Delete,     /// Delete the files/directories directly, i.e. without moving them to Trash
-        Trash,      /// Move the files/directories to Trash
+        Delete, /// Delete the files/directories directly, i.e. without moving them to Trash
+        Trash, /// Move the files/directories to Trash
         EmptyTrash, /// Empty the Trash
     };
 
@@ -124,7 +122,7 @@ public:
     enum ConfirmationType {
         DefaultConfirmation, ///< Do not ask if the user has previously set the "Do not ask again"
                              ///< checkbox (which is is shown in the message dialog invoked by askUserDelete())
-        ForceConfirmation,   ///< Always ask the user for confirmation
+        ForceConfirmation, ///< Always ask the user for confirmation
     };
 
     /**
@@ -148,7 +146,7 @@ public:
     virtual void askUserDelete(const QList<QUrl> &urls,
                                DeletionType deletionType,
                                ConfirmationType confirmationType,
-                               QWidget *parent) = 0;
+                               QWidget *parent = nullptr) = 0; // TODO KF6: replace QWidget* with QObject*
 
     enum MessageDialogType {
         QuestionYesNo = 1,
@@ -183,12 +181,12 @@ public:
                                        const QString &caption,
                                        const QString &buttonYes,
                                        const QString &buttonNo,
-                                       const QString &iconYes,
-                                       const QString &iconNo,
-                                       const QString &dontAskAgainName,
-                                       const QString &details,
-                                       const KIO::MetaData &sslMetaData,
-                                       QWidget *parent) = 0;
+                                       const QString &iconYes = {},
+                                       const QString &iconNo = {},
+                                       const QString &dontAskAgainName = {},
+                                       const QString &details = {},
+                                       const KIO::MetaData &sslMetaData = {},
+                                       QWidget *parent = nullptr) = 0; // TODO KF6: replace QWidget* with QObject*, document "widget or window"
 
 Q_SIGNALS:
     /**
@@ -219,10 +217,12 @@ Q_SIGNALS:
      * set to false
      * @param urls a list of urls to delete/trash
      * @param deletionType the deletion type to use, one of KIO::AskUserActionInterface::DeletionType
-     * @param parent the parent widget
+     * @param parent the parent widget passed to askUserDelete(), for request identification
      */
-    void askUserDeleteResult(bool allowDelete, const QList<QUrl> &urls,
-                             KIO::AskUserActionInterface::DeletionType deletionType, QWidget *parent);
+    void askUserDeleteResult(bool allowDelete,
+                             const QList<QUrl> &urls,
+                             KIO::AskUserActionInterface::DeletionType deletionType,
+                             QWidget *parent); // TODO KF6: replace QWidget* with QObject*
 
     /**
      * Implementations of this interface must emit this signal when the dialog invoked
@@ -231,7 +231,7 @@ Q_SIGNALS:
      *
      * @param result the exit code of the dialog, one of KIO::SlaveBase::ButtonCode enum
      */
-    void messageBoxResult(int result);
+    void messageBoxResult(int result); // TODO KF6: add a QObject* to identify requests? Or return an int from the request method and pass it back here?
 
 private:
     std::unique_ptr<AskUserActionInterfacePrivate> d;
