@@ -15,48 +15,46 @@
 
 #include <config-kiocore.h>
 
-#include <string.h>
 #include <qplatformdefs.h>
+#include <string.h>
 #ifdef Q_OS_WIN
 #include <qt_windows.h>
-#undef interface //windows.h defines this, breaks QtDBus since it has parameters named interface
+#undef interface // windows.h defines this, breaks QtDBus since it has parameters named interface
 #else
 #include <sys/utsname.h>
 #endif
 
+#include <QCache>
 #include <QCoreApplication>
-#include <QUrl>
-#include <QSslSocket>
+#ifndef KIO_ANDROID_STUB
+#include <QDBusInterface>
+#include <QDBusReply>
+#endif
 #include <QHostAddress>
 #include <QHostInfo>
-#include <QDBusReply>
-#include <QDBusInterface>
-#include <QCache>
 #include <QLocale>
-#include <QRegularExpression>
-#include <QStandardPaths>
 #include <QMimeDatabase>
+#include <QRegularExpression>
+#include <QSslSocket>
+#include <QStandardPaths>
+#include <QUrl>
 
-#if !defined(QT_NO_NETWORKPROXY) && (defined (Q_OS_WIN32) || defined(Q_OS_MAC))
+#if !defined(QT_NO_NETWORKPROXY) && (defined(Q_OS_WIN32) || defined(Q_OS_MAC))
 #include <QNetworkProxyFactory>
 #include <QNetworkProxyQuery>
 #endif
 
-#include <kio_version.h>
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <kio_version.h>
 
-#include <KMimeTypeTrader>
 #include <kprotocolinfofactory_p.h>
 
-#include "slaveconfig.h"
-#include "ioslave_defaults.h"
 #include "http_slave_defaults.h"
+#include "ioslave_defaults.h"
+#include "slaveconfig.h"
 
-#define QL1S(x)   QLatin1String(x)
-#define QL1C(x)   QLatin1Char(x)
-
-typedef QPair<QHostAddress, int> SubnetPair;
+using SubnetPair = QPair<QHostAddress, int>;
 
 /*
     Domain suffix match. E.g. return true if host is "cuzco.inka.de" and
@@ -78,10 +76,14 @@ static bool revmatch(const char *host, const char *nplist)
             hptr = shptr;
 
             // Try to find another domain or host in the list
-            while (--nptr >= nplist && *nptr != ',' && *nptr != ' ');
+            while (--nptr >= nplist && *nptr != ',' && *nptr != ' ') {
+                ;
+            }
 
             // Strip out multiple spaces and commas
-            while (--nptr >= nplist && (*nptr == ',' || *nptr == ' '));
+            while (--nptr >= nplist && (*nptr == ',' || *nptr == ' ')) {
+                ;
+            }
         } else {
             if (nptr == nplist || nptr[-1] == ',' || nptr[-1] == ' ') {
                 return true;
@@ -149,8 +151,9 @@ Q_GLOBAL_STATIC(KProtocolManagerPrivate, kProtocolManagerPrivate)
 
 static void syncOnExit()
 {
-    if (kProtocolManagerPrivate.exists())
+    if (kProtocolManagerPrivate.exists()) {
         kProtocolManagerPrivate()->sync();
+    }
 }
 
 KProtocolManagerPrivate::KProtocolManagerPrivate()
@@ -176,7 +179,7 @@ bool KProtocolManagerPrivate::shouldIgnoreProxyFor(const QUrl &url)
 
     // No proxy only applies to ManualProxy and EnvVarProxy types...
     if (useNoProxyList && noProxyFor.isEmpty()) {
-        QStringList noProxyForList(readNoProxyFor().split(QL1C(',')));
+        QStringList noProxyForList(readNoProxyFor().split(QLatin1Char(',')));
         QMutableStringListIterator it(noProxyForList);
         while (it.hasNext()) {
             SubnetPair subnet = QHostAddress::parseSubnet(it.next());
@@ -185,7 +188,7 @@ bool KProtocolManagerPrivate::shouldIgnoreProxyFor(const QUrl &url)
                 it.remove();
             }
         }
-        noProxyFor =  noProxyForList.join(QLatin1Char(','));
+        noProxyFor = noProxyForList.join(QLatin1Char(','));
     }
 
     if (!noProxyFor.isEmpty()) {
@@ -199,7 +202,7 @@ bool KProtocolManagerPrivate::shouldIgnoreProxyFor(const QUrl &url)
         // number, try the combination of "host:port". This allows
         // users to enter host:port in the No-proxy-For list.
         if (!isMatch && url.port() > 0) {
-            qhost += QL1C(':') + QString::number(url.port());
+            qhost += QLatin1Char(':') + QString::number(url.port());
             host = qhost.toLatin1();
             isMatch = revmatch(host.constData(), no_proxy.constData());
         }
@@ -218,7 +221,7 @@ bool KProtocolManagerPrivate::shouldIgnoreProxyFor(const QUrl &url)
         // If request url is not IP address, do a DNS lookup of the hostname.
         // TODO: Perhaps we should make configurable ?
         if (address.isNull()) {
-            //qDebug() << "Performing DNS lookup for" << host;
+            // qDebug() << "Performing DNS lookup for" << host;
             QHostInfo info = KIO::HostInfo::lookupHost(host, 2000);
             const QList<QHostAddress> addresses = info.addresses();
             if (!addresses.isEmpty()) {
@@ -227,7 +230,7 @@ bool KProtocolManagerPrivate::shouldIgnoreProxyFor(const QUrl &url)
         }
 
         if (!address.isNull()) {
-            for (const SubnetPair &subnet : qAsConst(noProxySubnets)) {
+            for (const SubnetPair &subnet : std::as_const(noProxySubnets)) {
                 if (address.isInSubnet(subnet)) {
                     isMatch = true;
                     break;
@@ -250,12 +253,9 @@ void KProtocolManagerPrivate::sync()
     }
 }
 
-#define PRIVATE_DATA \
-    KProtocolManagerPrivate *d = kProtocolManagerPrivate()
-
 void KProtocolManager::reparseConfiguration()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     if (d->http_config) {
         d->http_config->reparseConfiguration();
@@ -275,7 +275,7 @@ void KProtocolManager::reparseConfiguration()
 
 static KSharedConfig::Ptr config()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     Q_ASSERT(!d->mutex.tryLock()); // the caller must have locked the mutex
     if (!d->configPtr) {
         d->configPtr = KSharedConfig::openConfig(QStringLiteral("kioslaverc"), KConfig::NoGlobals);
@@ -306,14 +306,14 @@ QString KProtocolManagerPrivate::readNoProxyFor()
 
 QMap<QString, QString> KProtocolManager::entryMap(const QString &group)
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return config()->entryMap(group);
 }
 
 static KConfigGroup http_config()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     Q_ASSERT(!d->mutex.tryLock()); // the caller must have locked the mutex
     if (!d->http_config) {
         d->http_config = KSharedConfig::openConfig(QStringLiteral("kio_httprc"), KConfig::NoGlobals);
@@ -325,7 +325,7 @@ static KConfigGroup http_config()
 
 int KProtocolManager::readTimeout()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     KConfigGroup cg(config(), QString());
     int val = cg.readEntry("ReadTimeout", DEFAULT_READ_TIMEOUT);
@@ -334,7 +334,7 @@ int KProtocolManager::readTimeout()
 
 int KProtocolManager::connectTimeout()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     KConfigGroup cg(config(), QString());
     int val = cg.readEntry("ConnectTimeout", DEFAULT_CONNECT_TIMEOUT);
@@ -343,7 +343,7 @@ int KProtocolManager::connectTimeout()
 
 int KProtocolManager::proxyConnectTimeout()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     KConfigGroup cg(config(), QString());
     int val = cg.readEntry("ProxyConnectTimeout", DEFAULT_PROXY_CONNECT_TIMEOUT);
@@ -352,7 +352,7 @@ int KProtocolManager::proxyConnectTimeout()
 
 int KProtocolManager::responseTimeout()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     KConfigGroup cg(config(), QString());
     int val = cg.readEntry("ResponseTimeout", DEFAULT_RESPONSE_TIMEOUT);
@@ -368,21 +368,21 @@ bool KProtocolManager::useProxy()
 
 bool KProtocolManager::useReverseProxy()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return d->useReverseProxy();
 }
 
 KProtocolManager::ProxyType KProtocolManager::proxyType()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return d->proxyType();
 }
 
 KProtocolManager::ProxyAuthMode KProtocolManager::proxyAuthMode()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     KConfigGroup cg(config(), "Proxy Settings");
     return static_cast<ProxyAuthMode>(cg.readEntry("AuthMode", 0));
@@ -392,14 +392,14 @@ KProtocolManager::ProxyAuthMode KProtocolManager::proxyAuthMode()
 
 bool KProtocolManager::useCache()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return http_config().readEntry("UseCache", true);
 }
 
 KIO::CacheControl KProtocolManager::cacheControl()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     QString tmp = http_config().readEntry("cache");
     if (tmp.isEmpty()) {
@@ -410,39 +410,39 @@ KIO::CacheControl KProtocolManager::cacheControl()
 
 QString KProtocolManager::cacheDir()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return http_config().readPathEntry("CacheDir", QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QLatin1String("/kio_http"));
 }
 
 int KProtocolManager::maxCacheAge()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return http_config().readEntry("MaxCacheAge", DEFAULT_MAX_CACHE_AGE);
 }
 
 int KProtocolManager::maxCacheSize()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return http_config().readEntry("MaxCacheSize", DEFAULT_MAX_CACHE_SIZE);
 }
 
 QString KProtocolManager::noProxyFor()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return d->readNoProxyFor();
 }
 
 static QString adjustProtocol(const QString &scheme)
 {
-if (scheme.compare(QL1S("webdav"), Qt::CaseInsensitive) == 0) {
+    if (scheme.compare(QLatin1String("webdav"), Qt::CaseInsensitive) == 0) {
         return QStringLiteral("http");
     }
 
-    if (scheme.compare(QL1S("webdavs"), Qt::CaseInsensitive) == 0) {
+    if (scheme.compare(QLatin1String("webdavs"), Qt::CaseInsensitive) == 0) {
         return QStringLiteral("https");
     }
 
@@ -451,23 +451,25 @@ if (scheme.compare(QL1S("webdav"), Qt::CaseInsensitive) == 0) {
 
 QString KProtocolManager::proxyFor(const QString &protocol)
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return d->proxyFor(protocol);
 }
 
 QString KProtocolManagerPrivate::proxyFor(const QString &protocol)
 {
-    const QString key = adjustProtocol(protocol) + QL1S("Proxy");
+    const QString key = adjustProtocol(protocol) + QLatin1String("Proxy");
     QString proxyStr(config()->group("Proxy Settings").readEntry(key));
-    const int index = proxyStr.lastIndexOf(QL1C(' '));
+    const int index = proxyStr.lastIndexOf(QLatin1Char(' '));
 
-    if (index > -1)  {
-        bool ok = false;
-        const QStringRef portStr(proxyStr.rightRef(proxyStr.length() - index - 1));
-        portStr.toInt(&ok);
-        if (ok) {
-            proxyStr = proxyStr.leftRef(index) + QL1C(':') + portStr;
+    if (index > -1) {
+        const QStringView portStr = QStringView(proxyStr).right(proxyStr.length() - index - 1);
+        const bool isDigits = std::all_of(portStr.cbegin(), portStr.cend(), [](const QChar c) {
+            return c.isDigit();
+        });
+
+        if (isDigits) {
+            proxyStr = QStringView(proxyStr).left(index) + QLatin1Char(':') + portStr;
         } else {
             proxyStr.clear();
         }
@@ -499,16 +501,16 @@ QStringList KProtocolManagerPrivate::getSystemProxyFor(const QUrl &url)
         QUrl url;
         const QNetworkProxy::ProxyType type = proxy.type();
         if (type == QNetworkProxy::NoProxy || type == QNetworkProxy::DefaultProxy) {
-            proxies << QL1S("DIRECT");
+            proxies << QLatin1String("DIRECT");
             continue;
         }
 
         if (type == QNetworkProxy::HttpProxy || type == QNetworkProxy::HttpCachingProxy) {
-            url.setScheme(QL1S("http"));
+            url.setScheme(QLatin1String("http"));
         } else if (type == QNetworkProxy::Socks5Proxy) {
-            url.setScheme(QL1S("socks"));
+            url.setScheme(QLatin1String("socks"));
         } else if (type == QNetworkProxy::FtpCachingProxy) {
-            url.setScheme(QL1S("ftp"));
+            url.setScheme(QLatin1String("ftp"));
         }
 
         url.setHost(proxy.hostName());
@@ -531,9 +533,9 @@ QStringList KProtocolManagerPrivate::getSystemProxyFor(const QUrl &url)
     if (!proxyVar.isEmpty()) {
         QString proxy = QString::fromLocal8Bit(qgetenv(proxyVar.toLocal8Bit().constData())).trimmed();
         // Make sure the scheme of SOCKS proxy is always set to "socks://".
-        const int index = proxy.indexOf(QL1S("://"));
+        const int index = proxy.indexOf(QLatin1String("://"));
         const int offset = (index == -1) ? 0 : (index + 3);
-        proxy = QL1S("socks://") + proxy.midRef(offset);
+        proxy = QLatin1String("socks://") + QStringView(proxy).mid(offset);
         if (!proxy.isEmpty()) {
             proxies << proxy;
         }
@@ -546,7 +548,7 @@ QStringList KProtocolManager::proxiesForUrl(const QUrl &url)
 {
     QStringList proxyList;
 
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     if (!d->shouldIgnoreProxyFor(url)) {
         switch (d->proxyType()) {
@@ -556,13 +558,14 @@ QStringList KProtocolManager::proxiesForUrl(const QUrl &url)
             const QString protocol = adjustProtocol(u.scheme());
             u.setScheme(protocol);
 
+#ifndef KIO_ANDROID_STUB
             if (protocol.startsWith(QLatin1String("http")) || protocol.startsWith(QLatin1String("ftp"))) {
-                QDBusReply<QStringList> reply = QDBusInterface(QStringLiteral("org.kde.kded5"),
-                                                QStringLiteral("/modules/proxyscout"),
-                                                QStringLiteral("org.kde.KPAC.ProxyScout"))
-                                                .call(QStringLiteral("proxiesForUrl"), u.toString());
+                QDBusReply<QStringList> reply =
+                    QDBusInterface(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/proxyscout"), QStringLiteral("org.kde.KPAC.ProxyScout"))
+                        .call(QStringLiteral("proxiesForUrl"), u.toString());
                 proxyList = reply;
             }
+#endif
             break;
         }
         case EnvVarProxy:
@@ -577,13 +580,13 @@ QStringList KProtocolManager::proxiesForUrl(const QUrl &url)
             proxy = d->proxyFor(QStringLiteral("socks"));
             if (!proxy.isEmpty()) {
                 // Make sure the scheme of SOCKS proxy is always set to "socks://".
-                const int index = proxy.indexOf(QL1S("://"));
+                const int index = proxy.indexOf(QLatin1String("://"));
                 const int offset = (index == -1) ? 0 : (index + 3);
-                proxy = QL1S("socks://") + proxy.midRef(offset);
+                proxy = QLatin1String("socks://") + QStringView(proxy).mid(offset);
                 proxyList << proxy;
             }
+            break;
         }
-        break;
         case NoProxy:
             break;
         }
@@ -598,10 +601,11 @@ QStringList KProtocolManager::proxiesForUrl(const QUrl &url)
 
 void KProtocolManager::badProxy(const QString &proxy)
 {
-    QDBusInterface(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/proxyscout"))
-    .asyncCall(QStringLiteral("blackListProxy"), proxy);
+#ifndef KIO_ANDROID_STUB
+    QDBusInterface(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/proxyscout")).asyncCall(QStringLiteral("blackListProxy"), proxy);
+#endif
 
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     const QStringList keys(d->cachedProxyData.keys());
     for (const QString &key : keys) {
@@ -641,16 +645,15 @@ QString KProtocolManager::slaveProtocol(const QUrl &url, QStringList &proxyList)
     // Do not perform a proxy lookup for any url classified as a ":local" url or
     // one that does not have a host component or if proxy is disabled.
     QString protocol(url.scheme());
-    if (url.host().isEmpty()
-            || KProtocolInfo::protocolClass(protocol) == QL1S(":local")
-            || KProtocolManager::proxyType() == KProtocolManager::NoProxy) {
+    if (url.host().isEmpty() || KProtocolInfo::protocolClass(protocol) == QLatin1String(":local")
+        || KProtocolManager::proxyType() == KProtocolManager::NoProxy) {
         return protocol;
     }
 
     QString proxyCacheKey;
     extractProxyCacheKeyFromUrl(url, &proxyCacheKey);
 
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     // Look for cached proxy information to avoid more work.
     if (d->cachedProxyData.contains(proxyCacheKey)) {
@@ -663,9 +666,9 @@ QString KProtocolManager::slaveProtocol(const QUrl &url, QStringList &proxyList)
     const QStringList proxies = proxiesForUrl(url);
     const int count = proxies.count();
 
-    if (count > 0 && !(count == 1 && proxies.first() == QL1S("DIRECT"))) {
+    if (count > 0 && !(count == 1 && proxies.first() == QLatin1String("DIRECT"))) {
         for (const QString &proxy : proxies) {
-            if (proxy == QL1S("DIRECT")) {
+            if (proxy == QLatin1String("DIRECT")) {
                 proxyList << proxy;
             } else {
                 QUrl u(proxy);
@@ -678,11 +681,12 @@ QString KProtocolManager::slaveProtocol(const QUrl &url, QStringList &proxyList)
 
     // The idea behind slave protocols is not applicable to http
     // and webdav protocols as well as protocols unknown to KDE.
+    /* clang-format off */
     if (!proxyList.isEmpty()
-            && !protocol.startsWith(QLatin1String("http"))
-            && !protocol.startsWith(QLatin1String("webdav"))
-            && KProtocolInfo::isKnownProtocol(protocol)) {
-        for (const QString &proxy : qAsConst(proxyList)) {
+        && !protocol.startsWith(QLatin1String("http"))
+        && !protocol.startsWith(QLatin1String("webdav"))
+        && KProtocolInfo::isKnownProtocol(protocol)) { /* clang-format on */
+        for (const QString &proxy : std::as_const(proxyList)) {
             QUrl u(proxy);
             if (u.isValid() && KProtocolInfo::isKnownProtocol(u.scheme())) {
                 protocol = u.scheme();
@@ -702,7 +706,7 @@ QString KProtocolManager::slaveProtocol(const QUrl &url, QStringList &proxyList)
 QString KProtocolManager::userAgentForHost(const QString &hostname)
 {
     const QString sendUserAgent = KIO::SlaveConfig::self()->configData(QStringLiteral("http"), hostname.toLower(), QStringLiteral("SendUserAgent")).toLower();
-    if (sendUserAgent == QL1S("false")) {
+    if (sendUserAgent == QLatin1String("false")) {
         return QString();
     }
 
@@ -723,19 +727,6 @@ QString KProtocolManager::defaultUserAgent()
     return defaultUserAgent(modifiers);
 }
 
-static QString defaultUserAgentFromPreferredService()
-{
-    QString agentStr;
-
-    // Check if the default COMPONENT contains a custom default UA string...
-    KService::Ptr service = KMimeTypeTrader::self()->preferredService(QStringLiteral("text/html"),
-                            QStringLiteral("KParts/ReadOnlyPart"));
-    if (service && service->showInCurrentDesktop())
-        agentStr = service->property(QStringLiteral("X-KDE-Default-UserAgent"),
-                                     QVariant::String).toString();
-    return agentStr;
-}
-
 // This is not the OS, but the windowing system, e.g. X11 on Unix/Linux.
 static QString platform()
 {
@@ -752,11 +743,11 @@ static QString platform()
 
 QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     QString modifiers = _modifiers.toLower();
     if (modifiers.isEmpty()) {
-        modifiers = QStringLiteral(DEFAULT_USER_AGENT_KEYS);
+        modifiers = QString::fromLatin1(DEFAULT_USER_AGENT_KEYS);
     }
 
     if (d->modifiers == modifiers && !d->useragent.isEmpty()) {
@@ -765,177 +756,71 @@ QString KProtocolManager::defaultUserAgent(const QString &_modifiers)
 
     d->modifiers = modifiers;
 
-    /*
-       The following code attempts to determine the default user agent string
-       from the 'X-KDE-Default-UserAgent' property of the desktop file
-       for the preferred service that was configured to handle the 'text/html'
-       MIME type. If the preferred service's desktop file does not specify this
-       property, the long standing default user agent string will be used.
-       The following keyword placeholders are automatically converted when the
-       user agent string is read from the property:
-
-       %SECURITY%      Expands to"N" when SSL is not supported, otherwise it is ignored.
-       %OSNAME%        Expands to operating system name, e.g. Linux.
-       %OSVERSION%     Expands to operating system version, e.g. 2.6.32
-       %SYSTYPE%       Expands to machine or system type, e.g. i386
-       %PLATFORM%      Expands to windowing system, e.g. X11 on Unix/Linux.
-       %LANGUAGE%      Expands to default language in use, e.g. en-US.
-       %APPVERSION%    Expands to QCoreApplication applicationName()/applicationVerison(),
-                       e.g. Konqueror/4.5.0. If application name and/or application version
-                       number are not set, then "KDE" and the runtime KDE version numbers
-                       are used respectively.
-
-       All of the keywords are handled case-insensitively.
-    */
-
-    QString systemName, systemVersion, machine, supp;
+    QString systemName;
+    QString systemVersion;
+    QString machine;
+    QString supp;
     const bool sysInfoFound = getSystemNameVersionAndMachine(systemName, systemVersion, machine);
-    QString agentStr = defaultUserAgentFromPreferredService();
 
-    if (agentStr.isEmpty()) {
-        supp += platform();
+    supp += platform();
 
-        if (sysInfoFound) {
-            if (modifiers.contains(QL1C('o'))) {
-                supp += QL1S("; ") + systemName;
-                if (modifiers.contains(QL1C('v'))) {
-                    supp += QL1C(' ') + systemVersion;
-                }
-
-                if (modifiers.contains(QL1C('m'))) {
-                    supp += QL1C(' ') + machine;
-                }
+    if (sysInfoFound) {
+        if (modifiers.contains(QLatin1Char('o'))) {
+            supp += QLatin1String("; ") + systemName;
+            if (modifiers.contains(QLatin1Char('v'))) {
+                supp += QLatin1Char(' ') + systemVersion;
             }
 
-            if (modifiers.contains(QL1C('l'))) {
-                supp += QL1S("; ") + QLocale::languageToString(QLocale().language());
+            if (modifiers.contains(QLatin1Char('m'))) {
+                supp += QLatin1Char(' ') + machine;
             }
         }
 
-        // Full format: Mozilla/5.0 (Linux
-        d->useragent =
-            QL1S("Mozilla/5.0 (") +
-            supp +
-            QL1S(") KHTML/") +
-            QString::number(KIO_VERSION_MAJOR) +
-            QL1C('.') +
-            QString::number(KIO_VERSION_MINOR) +
-            QL1C('.') +
-            QString::number(KIO_VERSION_PATCH) +
-            QL1S(" (like Gecko) Konqueror/") +
-            QString::number(KIO_VERSION_MAJOR) +
-            QL1S(" KIO/") +
-            QString::number(KIO_VERSION_MAJOR) +
-            QL1C('.') +
-            QString::number(KIO_VERSION_MINOR);
-    } else {
-        QString appName = QCoreApplication::applicationName();
-        if (appName.isEmpty() || appName.startsWith(QLatin1String("kcmshell"), Qt::CaseInsensitive)) {
-            appName = QStringLiteral("KDE");
+        if (modifiers.contains(QLatin1Char('l'))) {
+            supp += QLatin1String("; ") + QLocale::languageToString(QLocale().language());
         }
-
-        QString appVersion = QCoreApplication::applicationVersion();
-        if (appVersion.isEmpty()) {
-            appVersion +=
-                QString::number(KIO_VERSION_MAJOR) +
-                QL1C('.') +
-                QString::number(KIO_VERSION_MINOR) +
-                QL1C('.') +
-                QString::number(KIO_VERSION_PATCH);
-        }
-
-        appName += QL1C('/') + appVersion;
-
-        agentStr.replace(QL1S("%appversion%"), appName, Qt::CaseInsensitive);
-
-        if (!QSslSocket::supportsSsl()) {
-            agentStr.replace(QLatin1String("%security%"), QL1S("N"), Qt::CaseInsensitive);
-        } else {
-            agentStr.remove(QStringLiteral("%security%"), Qt::CaseInsensitive);
-        }
-
-        if (sysInfoFound) {
-            // Platform (e.g. X11). It is no longer configurable from UI.
-            agentStr.replace(QL1S("%platform%"), platform(), Qt::CaseInsensitive);
-
-            // Operating system (e.g. Linux)
-            if (modifiers.contains(QL1C('o'))) {
-                agentStr.replace(QL1S("%osname%"), systemName, Qt::CaseInsensitive);
-
-                // OS version (e.g. 2.6.36)
-                if (modifiers.contains(QL1C('v'))) {
-                    agentStr.replace(QL1S("%osversion%"), systemVersion, Qt::CaseInsensitive);
-                } else {
-                    agentStr.remove(QStringLiteral("%osversion%"), Qt::CaseInsensitive);
-                }
-
-                // Machine type (i686, x86-64, etc.)
-                if (modifiers.contains(QL1C('m'))) {
-                    agentStr.replace(QL1S("%systype%"), machine, Qt::CaseInsensitive);
-                } else {
-                    agentStr.remove(QStringLiteral("%systype%"), Qt::CaseInsensitive);
-                }
-            } else {
-                agentStr.remove(QStringLiteral("%osname%"), Qt::CaseInsensitive);
-                agentStr.remove(QStringLiteral("%osversion%"), Qt::CaseInsensitive);
-                agentStr.remove(QStringLiteral("%systype%"), Qt::CaseInsensitive);
-            }
-
-            // Language (e.g. en_US)
-            if (modifiers.contains(QL1C('l'))) {
-                agentStr.replace(QL1S("%language%"), QLocale::languageToString(QLocale().language()), Qt::CaseInsensitive);
-            } else {
-                agentStr.remove(QStringLiteral("%language%"), Qt::CaseInsensitive);
-            }
-
-            // Clean up unnecessary separators that could be left over from the
-            // possible keyword removal above...
-            agentStr.replace(QRegularExpression(QStringLiteral("[(]\\s*[;]\\s*")), QStringLiteral("("));
-            agentStr.replace(QRegularExpression(QStringLiteral("[;]\\s*[;]\\s*")), QStringLiteral("; "));
-            agentStr.replace(QRegularExpression(QStringLiteral("\\s*[;]\\s*[)]")), QStringLiteral(")"));
-        } else {
-            agentStr.remove(QStringLiteral("%osname%"));
-            agentStr.remove(QStringLiteral("%osversion%"));
-            agentStr.remove(QStringLiteral("%platform%"));
-            agentStr.remove(QStringLiteral("%systype%"));
-            agentStr.remove(QStringLiteral("%language%"));
-        }
-
-        d->useragent = agentStr.simplified();
     }
 
-    //qDebug() << "USERAGENT STRING:" << d->useragent;
+    QString appName = QCoreApplication::applicationName();
+    if (appName.isEmpty() || appName.startsWith(QLatin1String("kcmshell"), Qt::CaseInsensitive)) {
+        appName = QStringLiteral("KDE");
+    }
+    QString appVersion = QCoreApplication::applicationVersion();
+    if (appVersion.isEmpty()) {
+        appVersion += QLatin1String(KIO_VERSION_STRING);
+    }
+
+    d->useragent = QLatin1String("Mozilla/5.0 (%1) ").arg(supp)
+        + QLatin1String("KIO/%1.%2 ").arg(QString::number(KIO_VERSION_MAJOR), QString::number(KIO_VERSION_MINOR))
+        + QLatin1String("%1/%2").arg(appName, appVersion);
+
+    // qDebug() << "USERAGENT STRING:" << d->useragent;
     return d->useragent;
 }
 
-QString KProtocolManager::userAgentForApplication(const QString &appName, const QString &appVersion,
-        const QStringList &extraInfo)
+QString KProtocolManager::userAgentForApplication(const QString &appName, const QString &appVersion, const QStringList &extraInfo)
 {
-    QString systemName, systemVersion, machine, info;
+    QString systemName;
+    QString systemVersion;
+    QString machine;
+    QString info;
 
     if (getSystemNameVersionAndMachine(systemName, systemVersion, machine)) {
-        info += systemName + QL1C('/') + systemVersion + QL1S("; ");
+        info += systemName + QLatin1Char('/') + systemVersion + QLatin1String("; ");
     }
 
-    info +=
-        QL1S("KDE/") +
-        QString::number(KIO_VERSION_MAJOR) +
-        QL1C('.') +
-        QString::number(KIO_VERSION_MINOR) +
-        QL1C('.') +
-        QString::number(KIO_VERSION_PATCH);
+    info += QLatin1String("KDE/") + QStringLiteral(KIO_VERSION_STRING);
 
     if (!machine.isEmpty()) {
-        info += QL1S("; ") + machine;
+        info += QLatin1String("; ") + machine;
     }
 
-    info += QL1S("; ") + extraInfo.join(QLatin1String("; "));
+    info += QLatin1String("; ") + extraInfo.join(QLatin1String("; "));
 
-    return (appName + QL1C('/') + appVersion + QStringLiteral(" (") + info + QL1C(')'));
+    return (appName + QLatin1Char('/') + appVersion + QStringLiteral(" (") + info + QLatin1Char(')'));
 }
 
-bool KProtocolManager::getSystemNameVersionAndMachine(
-    QString &systemName, QString &systemVersion, QString &machine)
+bool KProtocolManager::getSystemNameVersionAndMachine(QString &systemName, QString &systemVersion, QString &machine)
 {
 #if defined(Q_OS_WIN) && !defined(_WIN32_WCE)
     // we do not use unameBuf.sysname information constructed in kdewin32
@@ -945,14 +830,14 @@ bool KProtocolManager::getSystemNameVersionAndMachine(
     ZeroMemory(&versioninfo, sizeof(OSVERSIONINFOEX));
     // try calling GetVersionEx using the OSVERSIONINFOEX, if that fails, try using the OSVERSIONINFO
     versioninfo.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
-    bool ok = GetVersionEx((OSVERSIONINFO *) &versioninfo);
+    bool ok = GetVersionEx((OSVERSIONINFO *)&versioninfo);
     if (!ok) {
         versioninfo.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
-        ok = GetVersionEx((OSVERSIONINFO *) &versioninfo);
+        ok = GetVersionEx((OSVERSIONINFO *)&versioninfo);
     }
     if (ok) {
         systemVersion = QString::number(versioninfo.dwMajorVersion);
-        systemVersion +=  QL1C('.');
+        systemVersion += QLatin1Char('.');
         systemVersion += QString::number(versioninfo.dwMinorVersion);
     }
 #else
@@ -975,7 +860,7 @@ QString KProtocolManager::acceptLanguagesHeader()
     QStringList languageList = QLocale().uiLanguages();
 
     // Replace possible "C" in the language list with "en", unless "en" is
-    // already pressent. This is to keep user's priorities in order.
+    // already present. This is to keep user's priorities in order.
     // If afterwards "en" is still not present, append it.
     int idx = languageList.indexOf(QLatin1String("C"));
     if (idx != -1) {
@@ -994,7 +879,7 @@ QString KProtocolManager::acceptLanguagesHeader()
     KConfig acclangConf(QStringLiteral("accept-languages.codes"), KConfig::NoGlobals);
     KConfigGroup replacementCodes(&acclangConf, "ReplacementCodes");
     QStringList languageListFinal;
-    for (const QString &lang : qAsConst(languageList)) {
+    for (const QString &lang : std::as_const(languageList)) {
         const QStringList langs = replacementCodes.readEntry(lang, QStringList());
         if (langs.isEmpty()) {
             languageListFinal += lang;
@@ -1009,13 +894,13 @@ QString KProtocolManager::acceptLanguagesHeader()
     // the value evenly
     int prio = 10;
     QString header;
-    for (const QString &lang : qAsConst(languageListFinal)) {
+    for (const QString &lang : std::as_const(languageListFinal)) {
         header += lang;
         if (prio < 10) {
-            header += QL1S(";q=0.") + QString::number(prio);
+            header += QLatin1String(";q=0.") + QString::number(prio);
         }
         // do not add cosmetic whitespace in here : it is less compatible (#220677)
-        header += QL1C(',');
+        header += QLatin1Char(',');
         if (prio > 1) {
             --prio;
         }
@@ -1025,8 +910,8 @@ QString KProtocolManager::acceptLanguagesHeader()
     // Some of the languages may have country specifier delimited by
     // underscore, or modifier delimited by at-sign.
     // The header should use dashes instead.
-    header.replace(QL1C('_'), QL1C('-'));
-    header.replace(QL1C('@'), QL1C('-'));
+    header.replace(QLatin1Char('_'), QLatin1Char('-'));
+    header.replace(QLatin1Char('@'), QLatin1Char('-'));
 
     return header;
 }
@@ -1035,43 +920,43 @@ QString KProtocolManager::acceptLanguagesHeader()
 
 bool KProtocolManager::markPartial()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return config()->group(QByteArray()).readEntry("MarkPartial", true);
 }
 
 int KProtocolManager::minimumKeepSize()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return config()->group(QByteArray()).readEntry("MinimumKeepSize",
-            DEFAULT_MINIMUM_KEEP_SIZE);  // 5000 byte
+                                                   DEFAULT_MINIMUM_KEEP_SIZE); // 5000 byte
 }
 
 bool KProtocolManager::autoResume()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return config()->group(QByteArray()).readEntry("AutoResume", false);
 }
 
 bool KProtocolManager::persistentConnections()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return config()->group(QByteArray()).readEntry("PersistentConnections", true);
 }
 
 bool KProtocolManager::persistentProxyConnection()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return config()->group(QByteArray()).readEntry("PersistentProxyConnection", false);
 }
 
 QString KProtocolManager::proxyConfigScript()
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     return config()->group("Proxy Settings").readEntry("Proxy Config Script");
 }
@@ -1294,7 +1179,7 @@ QString KProtocolManager::defaultMimetype(const QUrl &url)
 
 QString KProtocolManager::protocolForArchiveMimetype(const QString &mimeType)
 {
-    PRIVATE_DATA;
+    KProtocolManagerPrivate *d = kProtocolManagerPrivate();
     QMutexLocker lock(&d->mutex);
     if (d->protocolForArchiveMimetypes.isEmpty()) {
         const QList<KProtocolInfoPrivate *> allProtocols = KProtocolInfoFactory::self()->allProtocols();
@@ -1315,5 +1200,4 @@ QString KProtocolManager::charsetFor(const QUrl &url)
 
 #undef PRIVATE_DATA
 
-
 #include "kprotocolmanager.moc"
