@@ -513,7 +513,7 @@ void KFilePreviewGeneratorPrivate::updateIcons(const KFileItemList &items)
     orderItems(orderedItems);
 
     m_pendingItems.reserve(m_pendingItems.size() + orderedItems.size());
-    for (const KFileItem &item : qAsConst(orderedItems)) {
+    for (const KFileItem &item : std::as_const(orderedItems)) {
         m_pendingItems.append(item);
     }
 
@@ -617,8 +617,8 @@ void KFilePreviewGeneratorPrivate::addToPreviewQueue(const KFileItem &item, cons
 
     const QString mimeType = item.mimetype();
     const int slashIndex = mimeType.indexOf(QLatin1Char('/'));
-    const QStringRef mimeTypeGroup = mimeType.leftRef(slashIndex);
-    if ((mimeTypeGroup != QLatin1String("image")) || !applyImageFrame(icon)) {
+    const auto mimeTypeGroup = QStringView(mimeType).left(slashIndex);
+    if (mimeTypeGroup != QLatin1String("image") || !applyImageFrame(icon)) {
         limitToSize(icon, m_viewAdapter->iconSize());
     }
 
@@ -649,7 +649,7 @@ void KFilePreviewGeneratorPrivate::slotPreviewJobFinished(KJob *job)
     m_previewJobs.removeAt(index);
 
     if (m_previewJobs.isEmpty()) {
-        for (const KFileItem &item : qAsConst(m_pendingItems)) {
+        for (const KFileItem &item : std::as_const(m_pendingItems)) {
             if (item.isMimeTypeKnown()) {
                 m_resolvedMimeTypes.append(item);
             }
@@ -734,7 +734,7 @@ void KFilePreviewGeneratorPrivate::dispatchIconUpdateQueue()
 
         if (m_previewShown) {
             // dispatch preview queue
-            for (const ItemInfo &preview : qAsConst(m_previews)) {
+            for (const ItemInfo &preview : std::as_const(m_previews)) {
                 const QModelIndex idx = dirModel->indexForUrl(preview.url);
                 if (idx.isValid() && (idx.column() == 0)) {
                     dirModel->setData(idx, QIcon(preview.pixmap), Qt::DecorationRole);
@@ -744,7 +744,7 @@ void KFilePreviewGeneratorPrivate::dispatchIconUpdateQueue()
         }
 
         // dispatch MIME type queue
-        for (const KFileItem &item : qAsConst(m_resolvedMimeTypes)) {
+        for (const KFileItem &item : std::as_const(m_resolvedMimeTypes)) {
             const QModelIndex idx = dirModel->indexForItem(item);
             dirModel->itemChanged(idx);
         }
@@ -767,7 +767,7 @@ void KFilePreviewGeneratorPrivate::dispatchIconUpdateQueue()
 void KFilePreviewGeneratorPrivate::pauseIconUpdates()
 {
     m_iconUpdatesPaused = true;
-    for (KJob *job : qAsConst(m_previewJobs)) {
+    for (KJob *job : std::as_const(m_previewJobs)) {
         Q_ASSERT(job);
         job->suspend();
     }
@@ -784,16 +784,13 @@ void KFilePreviewGeneratorPrivate::resumeIconUpdates()
     // queue is usually equal. So even when having a lot of elements the
     // nested loop is no performance bottle neck, as the inner loop is only
     // entered once in most cases.
-    for (const KFileItem &item : qAsConst(m_dispatchedItems)) {
-        KFileItemList::iterator begin = m_pendingItems.begin();
-        KFileItemList::iterator end = m_pendingItems.end();
-        for (KFileItemList::iterator it = begin; it != end; ++it) {
-            if ((*it).url() == item.url()) {
-                m_pendingItems.erase(it);
-                break;
-            }
-        }
+    for (const KFileItem &item : std::as_const(m_dispatchedItems)) {
+        auto it = std::remove_if(m_pendingItems.begin(), m_pendingItems.end(), [&item](const KFileItem &pending) {
+            return pending.url() == item.url();
+        });
+        m_pendingItems.erase(it, m_pendingItems.end());
     }
+
     m_dispatchedItems.clear();
 
     m_pendingVisibleIconUpdates = 0;
@@ -903,7 +900,7 @@ void KFilePreviewGeneratorPrivate::applyCutItemEffect(const KFileItemList &items
                 const QSize actualSize = icon.actualSize(m_viewAdapter->iconSize());
                 QPixmap pixmap = icon.pixmap(actualSize);
 
-                const QHash<QUrl, QPixmap>::const_iterator cacheIt = m_cutItemsCache.constFind(item.url());
+                const auto cacheIt = m_cutItemsCache.constFind(item.url());
                 if ((cacheIt == m_cutItemsCache.constEnd()) || (cacheIt->cacheKey() != pixmap.cacheKey())) {
                     pixmap = iconEffect->apply(pixmap, KIconLoader::Desktop, KIconLoader::DisabledState);
                     dirModel->setData(index, QIcon(pixmap), Qt::DecorationRole);
@@ -974,7 +971,7 @@ void KFilePreviewGeneratorPrivate::createPreviews(const KFileItemList &items)
     for (const KFileItem &item : items) {
         mimeType = item.mimetype();
         const int slashIndex = mimeType.indexOf(QLatin1Char('/'));
-        const QStringRef mimeTypeGroup = mimeType.leftRef(slashIndex);
+        const auto mimeTypeGroup = QStringView(mimeType).left(slashIndex);
         if (mimeTypeGroup == QLatin1String("image")) {
             imageItems.append(item);
         } else {
@@ -1019,7 +1016,7 @@ void KFilePreviewGeneratorPrivate::startPreviewJob(const KFileItemList &items, i
 
 void KFilePreviewGeneratorPrivate::killPreviewJobs()
 {
-    for (KJob *job : qAsConst(m_previewJobs)) {
+    for (KJob *job : std::as_const(m_previewJobs)) {
         Q_ASSERT(job);
         job->kill();
     }
@@ -1101,15 +1098,13 @@ void KFilePreviewGeneratorPrivate::delayedIconUpdate()
 
     KFileItemList itemList;
 
-    QHash<QUrl, bool>::const_iterator it = m_changedItems.constBegin();
-    while (it != m_changedItems.constEnd()) {
+    for (auto it = m_changedItems.cbegin(); it != m_changedItems.cend(); ++it) {
         const bool hasChanged = it.value();
         if (hasChanged) {
             const QModelIndex index = dirModel->indexForUrl(it.key());
             const KFileItem item = dirModel->itemForIndex(index);
             itemList.append(item);
         }
-        ++it;
     }
     m_changedItems.clear();
 
