@@ -7,38 +7,36 @@
 
 #include "kurlnavigatorbutton_p.h"
 
+#include "../pathhelpers_p.h"
 #include "kurlnavigator.h"
 #include "kurlnavigatormenu_p.h"
-#include "kdirsortfilterproxymodel.h"
-#include "../pathhelpers_p.h"
 
-#include <kio/job.h>
 #include <KLocalizedString>
 #include <KStringHandler>
+#include <kio/job.h>
 
-#include <QTimer>
-#include <QPainter>
-#include <QKeyEvent>
-#include <QStyleOption>
-#include <QMimeData>
 #include <QCollator>
+#include <QKeyEvent>
+#include <QMimeData>
+#include <QPainter>
+#include <QStyleOption>
+#include <QTimer>
 
 namespace KDEPrivate
 {
-
 QPointer<KUrlNavigatorMenu> KUrlNavigatorButton::m_subDirsMenu;
 
-KUrlNavigatorButton::KUrlNavigatorButton(const QUrl &url, QWidget *parent) :
-    KUrlNavigatorButtonBase(parent),
-    m_hoverArrow(false),
-    m_pendingTextChange(false),
-    m_replaceButton(false),
-    m_showMnemonic(false),
-    m_wheelSteps(0),
-    m_url(url),
-    m_subDir(),
-    m_openSubDirsTimer(nullptr),
-    m_subDirsJob(nullptr)
+KUrlNavigatorButton::KUrlNavigatorButton(const QUrl &url, KUrlNavigator *parent)
+    : KUrlNavigatorButtonBase(parent)
+    , m_hoverArrow(false)
+    , m_pendingTextChange(false)
+    , m_replaceButton(false)
+    , m_showMnemonic(false)
+    , m_wheelSteps(0)
+    , m_url(url)
+    , m_subDir()
+    , m_openSubDirsTimer(nullptr)
+    , m_subDirsJob(nullptr)
 {
     setAcceptDrops(true);
     setUrl(url);
@@ -74,15 +72,13 @@ void KUrlNavigatorButton::setUrl(const QUrl &url)
         QStringLiteral("mtp"),
     };
 
-    const bool startTextResolving = m_url.isValid() && !m_url.isLocalFile()
-                                && !protocolBlacklist.contains(m_url.scheme());
+    const bool startTextResolving = m_url.isValid() && !m_url.isLocalFile() && !protocolBlacklist.contains(m_url.scheme());
 
     if (startTextResolving) {
         m_pendingTextChange = true;
         KIO::StatJob *job = KIO::stat(m_url, KIO::HideProgressInfo);
-        connect(job, &KJob::result,
-                this, &KUrlNavigatorButton::statFinished);
-        emit startedTextResolving();
+        connect(job, &KJob::result, this, &KUrlNavigatorButton::statFinished);
+        Q_EMIT startedTextResolving();
     } else {
         setText(m_url.fileName().replace(QLatin1Char('&'), QLatin1String("&&")));
     }
@@ -157,7 +153,7 @@ void KUrlNavigatorButton::paintEvent(QPaintEvent *event)
     adjustedFont.setBold(m_subDir.isEmpty());
     painter.setFont(adjustedFont);
 
-    int buttonWidth  = width();
+    int buttonWidth = width();
     int preferredWidth = sizeHint().width();
     if (preferredWidth < minimumWidth()) {
         preferredWidth = minimumWidth();
@@ -270,7 +266,7 @@ void KUrlNavigatorButton::keyPressEvent(QKeyEvent *event)
     switch (event->key()) {
     case Qt::Key_Enter:
     case Qt::Key_Return:
-        emit clicked(m_url, Qt::LeftButton, event->modifiers());
+        Q_EMIT navigatorButtonActivated(m_url, Qt::LeftButton, event->modifiers());
         break;
     case Qt::Key_Down:
     case Qt::Key_Space:
@@ -286,7 +282,7 @@ void KUrlNavigatorButton::dropEvent(QDropEvent *event)
     if (event->mimeData()->hasUrls()) {
         setDisplayHintEnabled(DraggedHint, true);
 
-        emit urlsDropped(m_url, event);
+        Q_EMIT urlsDroppedOnNavButton(m_url, event);
 
         setDisplayHintEnabled(DraggedHint, false);
         update();
@@ -353,7 +349,7 @@ void KUrlNavigatorButton::mouseReleaseEvent(QMouseEvent *event)
     if (!isAboveArrow(event->x()) || (event->button() != Qt::LeftButton)) {
         // the mouse has been released above the text area and not
         // above the [>] button
-        emit clicked(m_url, event->button(), event->modifiers());
+        Q_EMIT navigatorButtonActivated(m_url, event->button(), event->modifiers());
         cancelSubDirsRequest();
     }
     KUrlNavigatorButtonBase::mouseReleaseEvent(event);
@@ -395,11 +391,12 @@ void KUrlNavigatorButton::startSubDirsJob()
     }
 
     const QUrl url = m_replaceButton ? KIO::upUrl(m_url) : m_url;
-    m_subDirsJob = KIO::listDir(url, KIO::HideProgressInfo, false /*no hidden files*/);
+    const KUrlNavigator *urlNavigator = qobject_cast<KUrlNavigator*>(parent());
+    Q_ASSERT(urlNavigator);
+    m_subDirsJob = KIO::listDir(url, KIO::HideProgressInfo, urlNavigator->showHiddenFolders());
     m_subDirs.clear(); // just to be ++safe
 
-    connect(m_subDirsJob, &KIO::ListJob::entries,
-            this, &KUrlNavigatorButton::addEntriesToSubDirs);
+    connect(m_subDirsJob, &KIO::ListJob::entries, this, &KUrlNavigatorButton::addEntriesToSubDirs);
 
     if (m_replaceButton) {
         connect(m_subDirsJob, &KJob::result, this, &KUrlNavigatorButton::replaceButton);
@@ -427,12 +424,12 @@ void KUrlNavigatorButton::addEntriesToSubDirs(KIO::Job *job, const KIO::UDSEntry
     }
 }
 
-void KUrlNavigatorButton::urlsDropped(QAction *action, QDropEvent *event)
+void KUrlNavigatorButton::slotUrlsDropped(QAction *action, QDropEvent *event)
 {
     const int result = action->data().toInt();
     QUrl url(m_url);
     url.setPath(concatPaths(url.path(), m_subDirs.at(result).first));
-    emit urlsDropped(url, event);
+    Q_EMIT urlsDroppedOnNavButton(url, event);
 }
 
 void KUrlNavigatorButton::slotMenuActionClicked(QAction *action, Qt::MouseButton button)
@@ -440,7 +437,7 @@ void KUrlNavigatorButton::slotMenuActionClicked(QAction *action, Qt::MouseButton
     const int result = action->data().toInt();
     QUrl url(m_url);
     url.setPath(concatPaths(url.path(), m_subDirs.at(result).first));
-    emit clicked(url, button, Qt::NoModifier);
+    Q_EMIT navigatorButtonActivated(url, button, Qt::NoModifier);
 }
 
 void KUrlNavigatorButton::statFinished(KJob *job)
@@ -455,29 +452,40 @@ void KUrlNavigatorButton::statFinished(KJob *job)
         }
         setText(name);
 
-        emit finishedTextResolving();
+        Q_EMIT finishedTextResolving();
     }
 }
 
 /**
- * Helper class for openSubDirsMenu
+ * Helper struct for sorting folder names
  */
-class NaturalLessThan
+struct FolderNameNaturalLessThan
 {
-public:
-    NaturalLessThan()
+    FolderNameNaturalLessThan(bool sortHiddenLast)
+        : m_sortHiddenLast(sortHiddenLast)
     {
         m_collator.setCaseSensitivity(Qt::CaseInsensitive);
         m_collator.setNumericMode(true);
     }
 
-    bool operator()(const QPair<QString, QString> &s1, const QPair<QString, QString> &s2)
+    bool operator()(const QPair<QString, QString> &a, const QPair<QString, QString> &b)
     {
-        return m_collator.compare(s1.first, s2.first) < 0;
+        if (m_sortHiddenLast) {
+            const bool isHiddenA = a.first.startsWith(QLatin1Char('.'));
+            const bool isHiddenB = b.first.startsWith(QLatin1Char('.'));
+            if (isHiddenA && !isHiddenB) {
+                return false;
+            }
+            if (!isHiddenA && isHiddenB) {
+                return true;
+            }
+        }
+        return m_collator.compare(a.first, b.first) < 0;
     }
 
 private:
     QCollator m_collator;
+    bool m_sortHiddenLast;
 };
 
 void KUrlNavigatorButton::openSubDirsMenu(KJob *job)
@@ -490,8 +498,10 @@ void KUrlNavigatorButton::openSubDirsMenu(KJob *job)
         return;
     }
 
-    NaturalLessThan nlt;
-    std::sort(m_subDirs.begin(), m_subDirs.end(), nlt);
+    const KUrlNavigator *urlNavigator = qobject_cast<KUrlNavigator*>(parent());
+    Q_ASSERT(urlNavigator);
+    FolderNameNaturalLessThan less(urlNavigator->showHiddenFolders() && urlNavigator->sortHiddenFoldersLast());
+    std::sort(m_subDirs.begin(), m_subDirs.end(), less);
     setDisplayHintEnabled(PopupActiveHint, true);
     update(); // ensure the button is drawn highlighted
 
@@ -506,7 +516,7 @@ void KUrlNavigatorButton::openSubDirsMenu(KJob *job)
 
     const bool leftToRight = (layoutDirection() == Qt::LeftToRight);
     const int popupX = leftToRight ? width() - arrowWidth() - BorderWidth : 0;
-    const QPoint popupPos  = parentWidget()->mapToGlobal(geometry().bottomLeft() + QPoint(popupX, 0));
+    const QPoint popupPos = parentWidget()->mapToGlobal(geometry().bottomLeft() + QPoint(popupX, 0));
 
     QPointer<QObject> guard(this);
 
@@ -535,8 +545,10 @@ void KUrlNavigatorButton::replaceButton(KJob *job)
         return;
     }
 
-    NaturalLessThan nlt;
-    std::sort(m_subDirs.begin(), m_subDirs.end(), nlt);
+    const KUrlNavigator *urlNavigator = qobject_cast<KUrlNavigator*>(parent());
+    Q_ASSERT(urlNavigator);
+    FolderNameNaturalLessThan less(urlNavigator->showHiddenFolders() && urlNavigator->sortHiddenFoldersLast());
+    std::sort(m_subDirs.begin(), m_subDirs.end(), less);
 
     // Get index of the directory that is shown currently in the button
     const QString currentDir = m_url.fileName();
@@ -560,7 +572,7 @@ void KUrlNavigatorButton::replaceButton(KJob *job)
 
     QUrl url(KIO::upUrl(m_url));
     url.setPath(concatPaths(url.path(), m_subDirs[targetIndex].first));
-    emit clicked(url, Qt::LeftButton, Qt::NoModifier);
+    Q_EMIT navigatorButtonActivated(url, Qt::LeftButton, Qt::NoModifier);
 
     m_subDirs.clear();
 }
@@ -653,14 +665,17 @@ void KUrlNavigatorButton::updateMinimumWidth()
 
 void KUrlNavigatorButton::initMenu(KUrlNavigatorMenu *menu, int startIndex)
 {
-    connect(menu, &KUrlNavigatorMenu::mouseButtonClicked,
-            this, &KUrlNavigatorButton::slotMenuActionClicked);
-    connect(menu, &KUrlNavigatorMenu::urlsDropped,
-            this, QOverload<QAction*,QDropEvent*>::of(&KUrlNavigatorButton::urlsDropped));
+    connect(menu, &KUrlNavigatorMenu::mouseButtonClicked, this, &KUrlNavigatorButton::slotMenuActionClicked);
+    connect(menu, &KUrlNavigatorMenu::urlsDropped, this, &KUrlNavigatorButton::slotUrlsDropped);
+
+    // So that triggering a menu item with the keyboard works
+    connect(menu, &QMenu::triggered, this, [this](QAction *act) {
+        slotMenuActionClicked(act, Qt::LeftButton);
+    });
 
     menu->setLayoutDirection(Qt::LeftToRight);
 
-    const int maxIndex = startIndex + 30;  // Don't show more than 30 items in a menu
+    const int maxIndex = startIndex + 30; // Don't show more than 30 items in a menu
     const int lastIndex = qMin(m_subDirs.count() - 1, maxIndex);
     for (int i = startIndex; i <= lastIndex; ++i) {
         const QString subDirName = m_subDirs[i].first;
