@@ -21,15 +21,18 @@
 #include <KLocalizedString>
 #include <KWindowSystem>
 
+#ifndef Q_OS_ANDROID
 #include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusReply>
+#endif
 #include <QDir>
 #include <QFileInfo>
 #include <QGuiApplication>
 #include <QProcess>
 #include <QStandardPaths>
 #include <QString>
+#include <QTimer>
 #include <QUuid>
 
 #ifdef Q_OS_WIN
@@ -89,6 +92,7 @@ KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
     qCDebug(KIO_GUI) << "Starting process:" << args;
     *instance->m_process << args;
 
+#ifndef Q_OS_ANDROID
     enum DiscreteGpuCheck { NotChecked, Present, Absent };
     static DiscreteGpuCheck s_gpuCheck = NotChecked;
 
@@ -112,6 +116,7 @@ KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
     if (service->runOnDiscreteGpu() && s_gpuCheck == Present) {
         instance->m_process->setEnv(QStringLiteral("DRI_PRIME"), QStringLiteral("1"));
     }
+#endif
 
     QString workingDir(service->workingDirectory());
     if (workingDir.isEmpty() && !urls.isEmpty() && urls.first().isLocalFile()) {
@@ -153,22 +158,49 @@ KProcessRunner *KProcessRunner::fromCommand(const QString &cmd,
     } else
 #endif
         instance->m_process->setShellCommand(cmd);
+
+    instance->initFromDesktopName(desktopName, execName, iconName, asn, workingDirectory, environment);
+    return instance;
+}
+
+KProcessRunner *KProcessRunner::fromExecutable(const QString &executable,
+                                               const QStringList &args,
+                                               const QString &desktopName,
+                                               const QString &iconName,
+                                               const QByteArray &asn,
+                                               const QString &workingDirectory,
+                                               const QProcessEnvironment &environment)
+{
+    auto instance = makeInstance();
+
+    instance->m_executable = KIO::DesktopExecParser::executablePath(executable);
+    instance->m_process->setProgram(executable, args);
+    instance->initFromDesktopName(desktopName, executable, iconName, asn, workingDirectory, environment);
+    return instance;
+}
+
+void KProcessRunner::initFromDesktopName(const QString &desktopName,
+                                         const QString &execName,
+                                         const QString &iconName,
+                                         const QByteArray &asn,
+                                         const QString &workingDirectory,
+                                         const QProcessEnvironment &environment)
+{
     if (!workingDirectory.isEmpty()) {
-        instance->m_process->setWorkingDirectory(workingDirectory);
+        m_process->setWorkingDirectory(workingDirectory);
     }
-    instance->m_process->setProcessEnvironment(environment);
+    m_process->setProcessEnvironment(environment);
     if (!desktopName.isEmpty()) {
         KService::Ptr service = KService::serviceByDesktopName(desktopName);
         if (service) {
-            if (instance->m_executable.isEmpty()) {
-                instance->m_executable = KIO::DesktopExecParser::executablePath(service->exec());
+            if (m_executable.isEmpty()) {
+                m_executable = KIO::DesktopExecParser::executablePath(service->exec());
             }
-            instance->init(service, service->entryPath(), service->name(), service->icon(), asn);
-            return instance;
+            init(service, service->entryPath(), service->name(), service->icon(), asn);
+            return;
         }
     }
-    instance->init(KService::Ptr(), QString{}, execName /*user-visible name*/, iconName, asn);
-    return instance;
+    init(KService::Ptr(), QString{}, execName /*user-visible name*/, iconName, asn);
 }
 
 void KProcessRunner::init(const KService::Ptr &service,
@@ -228,14 +260,13 @@ void KProcessRunner::init(const KService::Ptr &service,
     Q_UNUSED(iconName);
 #endif
 
-    bool waitingForXdgToken = false;
     if (KWindowSystem::isPlatformWayland()) {
         if (!asn.isEmpty()) {
             m_process->setEnv(QStringLiteral("XDG_ACTIVATION_TOKEN"), QString::fromUtf8(asn));
         } else {
             bool silent;
             QByteArray wmclass;
-            const bool startup_notify = m_service && KIOGuiPrivate::checkStartupNotify(m_service.data(), &silent, &wmclass);
+            const bool startup_notify = service && KIOGuiPrivate::checkStartupNotify(service.data(), &silent, &wmclass);
             if (startup_notify && !silent) {
                 auto window = qGuiApp->focusWindow();
                 if (!window && !qGuiApp->allWindows().isEmpty()) {
@@ -243,7 +274,7 @@ void KProcessRunner::init(const KService::Ptr &service,
                 }
                 if (window) {
                     const int launchedSerial = KWindowSystem::lastInputSerial(window);
-                    waitingForXdgToken = true;
+                    m_waitingForXdgToken = true;
                     connect(this, &KProcessRunner::xdgActivationTokenArrived, m_process.get(), [this] {
                         startProcess();
                     });
@@ -254,6 +285,7 @@ void KProcessRunner::init(const KService::Ptr &service,
                                 if (tokenSerial == launchedSerial) {
                                     m_process->setEnv(QStringLiteral("XDG_ACTIVATION_TOKEN"), token);
                                     Q_EMIT xdgActivationTokenArrived();
+                                    m_waitingForXdgToken = false;
                                 }
                             });
                     KWindowSystem::requestXdgActivationToken(window, launchedSerial, QFileInfo(m_serviceEntryPath).completeBaseName());
@@ -266,6 +298,9 @@ void KProcessRunner::init(const KService::Ptr &service,
         m_service = service;
         // Store the desktop name, used by debug output and for the systemd unit name
         m_desktopName = service->menuId();
+        if (m_desktopName.isEmpty() && m_executable == QLatin1String("systemsettings5") && m_service->hasServiceType(QLatin1String("KCModule"))) {
+            m_desktopName = QStringLiteral("systemsettings.desktop");
+        }
         if (m_desktopName.endsWith(QLatin1String(".desktop"))) { // always true, in theory
             m_desktopName.chop(strlen(".desktop"));
         }
@@ -282,14 +317,14 @@ void KProcessRunner::init(const KService::Ptr &service,
         m_description = userVisibleName;
     }
 
-    if (!waitingForXdgToken) {
+    if (!m_waitingForXdgToken) {
         startProcess();
     }
 }
 
 void ForkingProcessRunner::startProcess()
 {
-    connect(m_process.get(), QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &ForkingProcessRunner::slotProcessExited);
+    connect(m_process.get(), qOverload<int, QProcess::ExitStatus>(&QProcess::finished), this, &ForkingProcessRunner::slotProcessExited);
     connect(m_process.get(), &QProcess::started, this, &ForkingProcessRunner::slotProcessStarted, Qt::QueuedConnection);
     connect(m_process.get(), &QProcess::errorOccurred, this, &ForkingProcessRunner::slotProcessError);
     m_process->start();
@@ -297,6 +332,12 @@ void ForkingProcessRunner::startProcess()
 
 bool ForkingProcessRunner::waitForStarted(int timeout)
 {
+    if (m_process->state() == QProcess::NotRunning && m_waitingForXdgToken) {
+        QEventLoop loop;
+        QObject::connect(m_process.get(), &QProcess::stateChanged, &loop, &QEventLoop::quit);
+        QTimer::singleShot(timeout, &loop, &QEventLoop::quit);
+        loop.exec();
+    }
     return m_process->waitForStarted(timeout);
 }
 
@@ -406,7 +447,7 @@ bool KIOGuiPrivate::checkStartupNotify(const KService *service, bool *silent_arg
             wmclass = '0';
             silent = true;
 #else // That unfortunately doesn't work, when the launched non-compliant application
-      // launches another one that is compliant and there is any delay inbetween (bnc:#343359)
+      // launches another one that is compliant and there is any delay in between (bnc:#343359)
             return false;
 #endif
         }
