@@ -11,23 +11,24 @@
 #include "kshorturifilter.h"
 #include "../pathhelpers_p.h" // concatPaths(), isAbsoluteLocalPath()
 
-#include <QDir>
 #include <QDBusConnection>
+#include <QDir>
 #include <QLoggingCategory>
 #include <qplatformdefs.h>
 
-#include <KLocalizedString>
-#include <KPluginFactory>
-#include <kprotocolinfo.h>
+#include <KApplicationTrader>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KApplicationTrader>
+#include <KLocalizedString>
+#include <KPluginFactory>
 #include <KService>
-#include <kurlauthorized.h>
 #include <KUser>
+#include <kprotocolinfo.h>
+#include <kurlauthorized.h>
 
-namespace {
-QLoggingCategory category("kf.kio.urifilters.shorturi", QtWarningMsg);
+namespace
+{
+Q_LOGGING_CATEGORY(category, "kf.kio.urifilters.shorturi", QtWarningMsg)
 }
 
 /**
@@ -40,15 +41,12 @@ QLoggingCategory category("kf.kio.urifilters.shorturi", QtWarningMsg);
 
 typedef QMap<QString, QString> EntryMap;
 
-static QRegularExpression sEnvVarExp(QStringLiteral("\\$[a-zA-Z_][a-zA-Z0-9_]*"));
-
 static bool isPotentialShortURL(const QString &cmd)
 {
     // Host names and IPv4 address...
     // Exclude ".." and paths starting with "../", these are used to go up in a filesystem
     // dir hierarchy
-    if (cmd != QLatin1String("..") && !cmd.startsWith(QLatin1String("../"))
-        && cmd.contains(QLatin1Char('.'))) {
+    if (cmd != QLatin1String("..") && !cmd.startsWith(QLatin1String("../")) && cmd.contains(QLatin1Char('.'))) {
         return true;
     }
 
@@ -69,7 +67,7 @@ static QString removeArgs(const QString &_cmd)
         int spacePos = 0;
 
         do {
-            spacePos = cmd.indexOf(QLatin1Char(' '), spacePos+1);
+            spacePos = cmd.indexOf(QLatin1Char(' '), spacePos + 1);
         } while (spacePos > 1 && cmd[spacePos - 1] == QLatin1Char('\\'));
 
         if (spacePos > 0) {
@@ -93,8 +91,8 @@ static bool isKnownProtocol(const QString &protocol)
 KShortUriFilter::KShortUriFilter(QObject *parent, const QVariantList & /*args*/)
     : KUriFilterPlugin(QStringLiteral("kshorturifilter"), parent)
 {
-    QDBusConnection::sessionBus().connect(QString(), QStringLiteral("/"), QStringLiteral("org.kde.KUriFilterPlugin"),
-                                          QStringLiteral("configure"), this, SLOT(configure()));
+    QDBusConnection::sessionBus()
+        .connect(QString(), QStringLiteral("/"), QStringLiteral("org.kde.KUriFilterPlugin"), QStringLiteral("configure"), this, SLOT(configure()));
     configure();
 }
 
@@ -113,7 +111,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
      * hackable and is missing a config dialog.
      */
 
-    //QUrl url = data.uri();
+    // QUrl url = data.uri();
     QString cmd = data.typedString();
 
     int firstNonSlash = 0;
@@ -138,10 +136,9 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
     if (cmd.count(QLatin1Char('@')) > 1) {
         const int lastIndex = cmd.lastIndexOf(QLatin1Char('@'));
         // Percent encode all but the last '@'.
-        QString encodedCmd = QString::fromUtf8(QUrl::toPercentEncoding(cmd.left(lastIndex), QByteArrayLiteral(":/")));
-        encodedCmd += cmd.midRef(lastIndex);
-        cmd = encodedCmd;
-        url.setUrl(encodedCmd);
+        const auto suffix = QStringView(cmd).mid(lastIndex);
+        cmd = QString::fromUtf8(QUrl::toPercentEncoding(cmd.left(lastIndex), QByteArrayLiteral(":/"))) + suffix;
+        url.setUrl(cmd);
     }
 
     const bool isMalformed = !url.isValid();
@@ -151,8 +148,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
 
     // Fix misparsing of "foo:80", QUrl thinks "foo" is the protocol and "80" is the path.
     // However, be careful not to do that for valid hostless URLs, e.g. file:///foo!
-    if (!protocol.isEmpty() && url.host().isEmpty() && !url.path().isEmpty()
-        && cmd.contains(QLatin1Char(':')) && !isKnownProtocol(protocol)) {
+    if (!protocol.isEmpty() && url.host().isEmpty() && !url.path().isEmpty() && cmd.contains(QLatin1Char(':')) && !isKnownProtocol(protocol)) {
         protocol.clear();
     }
 
@@ -163,24 +159,23 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
     // executable and only the argument part, if any, changed! (Dawit)
     // You mean caching the last filtering, to try and reuse it, to save stat()s? (David)
 
-    const QString starthere_proto = QStringLiteral("start-here:");
-    if (cmd.indexOf(starthere_proto) == 0) {
+    const QLatin1String starthere_proto("start-here:");
+    if (cmd.startsWith(starthere_proto)) {
         setFilteredUri(data, QUrl(QStringLiteral("system:/")));
         setUriType(data, KUriFilterData::LocalDir);
         return true;
     }
 
     // Handle MAN & INFO pages shortcuts...
-    const QString man_proto = QStringLiteral("man:");
-    const QString info_proto = QStringLiteral("info:");
-    if (cmd.startsWith(QLatin1Char('#'))
-        || cmd.indexOf(man_proto) == 0
-        || cmd.indexOf(info_proto) == 0) {
-        if (cmd.leftRef(2) == QLatin1String("##")) {
-            cmd = QLatin1String("info:/") + cmd.midRef(2);
+    const QLatin1String man_proto("man:");
+    const QLatin1String info_proto("info:");
+    if (cmd.startsWith(QLatin1Char('#')) || cmd.startsWith(man_proto) || cmd.startsWith(info_proto)) {
+        QStringView sview(cmd);
+        if (cmd.startsWith(QLatin1String("##"))) {
+            cmd = QLatin1String("info:/") + sview.mid(2);
         } else if (cmd.startsWith(QLatin1Char('#'))) {
-            cmd = QLatin1String("man:/") + cmd.midRef(1);
-        } else if ((cmd == info_proto) || (cmd == man_proto)) {
+            cmd = QLatin1String("man:/") + sview.mid(1);
+        } else if (cmd == info_proto || cmd == man_proto) {
             cmd += QLatin1Char('/');
         }
 
@@ -216,8 +211,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
             // Split path from ref/query
             // but not for "/tmp/a#b", if "a#b" is an existing file,
             // or for "/tmp/a?b" (#58990)
-            if ((url.hasFragment() || !url.query().isEmpty())
-                && !url.path().endsWith(QLatin1Char('/'))) { // /tmp/?foo is a namefilter, not a query
+            if ((url.hasFragment() || !url.query().isEmpty()) && !url.path().endsWith(QLatin1Char('/'))) { // /tmp/?foo is a namefilter, not a query
                 path = url.path();
                 ref = url.fragment();
                 qCDebug(category) << "isLocalFile set path to" << path << "and ref to" << ref;
@@ -244,7 +238,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
         if (slashPos == 1) { // ~/
             path.replace(0, 1, QDir::homePath());
         } else { // ~username/
-            const QString userName(path.mid(1, slashPos-1));
+            const QString userName(path.mid(1, slashPos - 1));
             KUser user(userName);
             if (user.isValid() && !user.homeDir().isEmpty()) {
                 path.replace(0, slashPos, user.homeDir());
@@ -263,11 +257,12 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
         expanded = true;
     } else if (path.startsWith(QLatin1Char('$'))) {
         // Environment variable expansion.
-        auto match = sEnvVarExp.match(path);
+        static const QRegularExpression envVarExp(QStringLiteral("\\$[a-zA-Z_][a-zA-Z0-9_]*"));
+        const auto match = envVarExp.match(path);
         if (match.hasMatch()) {
-            const QByteArray exp = qgetenv(path.midRef(1, match.capturedLength() - 1).toLocal8Bit().data());
+            const QByteArray exp = qgetenv(QStringView(path).mid(1, match.capturedLength(0) - 1).toLocal8Bit().constData());
             if (!exp.isEmpty()) {
-                path.replace(0, match.capturedLength(), QFile::decodeName(exp));
+                path.replace(0, match.capturedLength(0), QFile::decodeName(exp));
                 expanded = true;
             }
         }
@@ -330,7 +325,8 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
             // Support for name filter (/foo/*.txt), see also KonqMainWindow::detectNameFilter
             // If the app using this filter doesn't support it, well, it'll simply error out itself
             int lastSlash = path.lastIndexOf(QLatin1Char('/'));
-            if (lastSlash > -1 && path.indexOf(QLatin1Char(' '), lastSlash) == -1) { // no space after last slash, otherwise it's more likely command-line arguments
+            if (lastSlash > -1
+                && path.indexOf(QLatin1Char(' '), lastSlash) == -1) { // no space after last slash, otherwise it's more likely command-line arguments
                 QString fileName = path.mid(lastSlash + 1);
                 QString testPath = path.left(lastSlash);
                 if ((fileName.indexOf(QLatin1Char('*')) != -1 || fileName.indexOf(QLatin1Char('[')) != -1 || fileName.indexOf(QLatin1Char('?')) != -1)
@@ -423,7 +419,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
     if (!cmd.contains(QLatin1Char(' '))) {
         // Okay this is the code that allows users to supply custom matches for specific
         // URLs using Qt's QRegularExpression class.
-        for (const URLHint &hint : qAsConst(m_urlHints)) {
+        for (const URLHint &hint : std::as_const(m_urlHints)) {
             qCDebug(category) << "testing regexp for" << hint.prepend;
             if (hint.hintRe.match(cmd).capturedStart() == 0) {
                 const QString cmdStr = hint.prepend + cmd;
@@ -482,14 +478,16 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
     return false;
 }
 
+// TODO KF6: unused, remove
 KCModule *KShortUriFilter::configModule(QWidget *, const char *) const
 {
-    return nullptr; //new KShortUriOptions( parent, name );
+    return nullptr; // new KShortUriOptions( parent, name );
 }
 
+// TODO KF6: unused, remove
 QString KShortUriFilter::configName() const
 {
-//    return i18n("&ShortURLs"); we don't have a configModule so no need for a configName that confuses translators
+    //    return i18n("&ShortURLs"); we don't have a configModule so no need for a configName that confuses translators
     return KUriFilterPlugin::configName();
 }
 
@@ -498,7 +496,7 @@ void KShortUriFilter::configure()
     KConfig config(objectName() + QStringLiteral("rc"), KConfig::NoGlobals);
     KConfigGroup cg(config.group(""));
 
-    m_strDefaultUrlScheme = cg.readEntry("DefaultProtocol", QStringLiteral("http://"));
+    m_strDefaultUrlScheme = cg.readEntry("DefaultProtocol", QStringLiteral("https://"));
     const EntryMap patterns = config.entryMap(QStringLiteral("Pattern"));
     const EntryMap protocols = config.entryMap(QStringLiteral("Protocol"));
     KConfigGroup typeGroup(&config, "Type");
