@@ -25,7 +25,7 @@
 #include <KIO/FileUndoManager>
 #include <KJobWidgets>
 #include <KLocalizedString>
-#include <KPluginLoader>
+#include <KPluginFactory>
 #include <KPluginMetaData>
 #include <KProtocolManager>
 #include <KService>
@@ -179,10 +179,10 @@ void DropMenu::addExtraActions(const QList<QAction *> &appActions, const QList<Q
     removeAction(m_cancelAction);
 
     removeAction(m_extraActionsSeparator);
-    for (QAction *action : qAsConst(m_appActions)) {
+    for (QAction *action : std::as_const(m_appActions)) {
         removeAction(action);
     }
-    for (QAction *action : qAsConst(m_pluginActions)) {
+    for (QAction *action : std::as_const(m_pluginActions)) {
         removeAction(action);
     }
 
@@ -304,18 +304,14 @@ void DropJobPrivate::fillPopupMenu(KIO::DropMenu *popup)
 
 void DropJobPrivate::addPluginActions(KIO::DropMenu *popup, const KFileItemListProperties &itemProps)
 {
-    const QVector<KPluginMetaData> plugin_offers = KPluginLoader::findPlugins(QStringLiteral("kf5/kio_dnd"));
-    for (const KPluginMetaData &service : plugin_offers) {
-        KPluginFactory *factory = KPluginLoader(service.fileName()).factory();
-        if (factory) {
-            KIO::DndPopupMenuPlugin *plugin = factory->create<KIO::DndPopupMenuPlugin>();
-            if (plugin) {
-                const auto actions = plugin->setup(itemProps, m_destUrl);
-                for (auto action : actions) {
-                    action->setParent(popup);
-                }
-                m_pluginActions += actions;
+    const QVector<KPluginMetaData> plugin_offers = KPluginMetaData::findPlugins(QStringLiteral("kf5/kio_dnd"));
+    for (const KPluginMetaData &data : plugin_offers) {
+        if (auto plugin = KPluginFactory::instantiatePlugin<KIO::DndPopupMenuPlugin>(data).plugin) {
+            const auto actions = plugin->setup(itemProps, m_destUrl);
+            for (auto action : actions) {
+                action->setParent(popup);
             }
+            m_pluginActions += actions;
         }
     }
 
@@ -328,7 +324,7 @@ void DropJob::setApplicationActions(const QList<QAction *> &actions)
 
     d->m_appActions = actions;
 
-    for (KIO::DropMenu *menu : qAsConst(d->m_menus)) {
+    for (KIO::DropMenu *menu : std::as_const(d->m_menus)) {
         menu->addExtraActions(d->m_appActions, d->m_pluginActions);
     }
 }
@@ -341,7 +337,7 @@ void DropJob::showMenu(const QPoint &p, QAction *atAction)
         return;
     }
 
-    for (KIO::DropMenu *menu : qAsConst(d->m_menus)) {
+    for (KIO::DropMenu *menu : std::as_const(d->m_menus)) {
         menu->popup(p, atAction);
     }
 }
@@ -554,7 +550,7 @@ void DropJobPrivate::handleDropToDesktopFile()
         // Drop to application -> start app with urls as argument
         KService::Ptr service(new KService(destFile));
         // Can't use setParentJob() because ApplicationLauncherJob isn't a KIO::Job,
-        // intead pass q as parent so that KIO::delegateExtension() can find a delegate
+        // instead pass q as parent so that KIO::delegateExtension() can find a delegate
         KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(service, q);
         job->setUrls(m_urls);
         QObject::connect(job, &KJob::result, q, [=]() {
@@ -587,7 +583,7 @@ void DropJobPrivate::handleDropToExecutable()
     // Launch executable for each of the files
     QStringList args;
     args.reserve(m_urls.size());
-    for (const QUrl &url : qAsConst(m_urls)) {
+    for (const QUrl &url : std::as_const(m_urls)) {
         args << url.toLocalFile(); // assume local files
     }
     QProcess::startDetached(m_destUrl.toLocalFile(), args);
