@@ -1,20 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Wilco Greven <greven@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Wilco Greven <greven@kde.org>
 
-    library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KURLREQUESTERDIALOG_H
@@ -61,12 +49,11 @@ public:
      * @param text   Text of the label
      * @param parent The parent object of this widget.
      */
-    KUrlRequesterDialog(const QUrl &url, const QString &text,
-                        QWidget *parent);
+    KUrlRequesterDialog(const QUrl &url, const QString &text, QWidget *parent);
     /**
      * Destructs the dialog.
      */
-    ~KUrlRequesterDialog();
+    ~KUrlRequesterDialog() override;
 
     /**
      * Returns the fully qualified filename.
@@ -80,8 +67,7 @@ public:
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The caption to use for the dialog.
      */
-    static QUrl getUrl(const QUrl &url = QUrl(),
-                       QWidget *parent = nullptr, const QString &caption = QString());
+    static QUrl getUrl(const QUrl &url = QUrl(), QWidget *parent = nullptr, const QString &caption = QString());
 
 #if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
@@ -107,4 +93,3 @@ private:
 };
 
 #endif // KURLREQUESTERDIALOG_H
-
